Learn R Programming

vse4ts (version 1.0.0)

vse4ts-package: vse4ts: Identify Memory Patterns in Time Series Using Variance Scale Exponent

Description

Methods for calculating the variance scale exponent to identify memory patterns in time series data. Includes tests for white noise, short memory, and long memory. See Fu, H. et al. (2018) tools:::Rd_expr_doi("10.1016/j.physa.2018.06.092").

Arguments

Author

Maintainer: Mengyang Zheng mengyang.zheng@outlook.com

Authors:

See Also